@@ -5,24 +5,18 @@ mod command;
 mod manifest;
 mod metadata;
 
+use atty::Stream;
 use clap::Parser;
 use tracing_error::ErrorLayer;
 use tracing_subscriber::{layer::SubscriberExt, util::SubscriberInitExt, EnvFilter};
 
-const SUPPORTED_MAJOR_VERSIONS: &[u16] = &[10, 11, 12, 13, 14];
-
 trait CommandExecute {
     fn execute(self) -> eyre::Result<()>;
 }
 
 /// `cargo` stub for `cargo-pgx` (you probably meant to run `cargo pgx`)
 #[derive(clap::Parser, Debug)]
-#[clap(
-    name = "cargo",
-    bin_name = "cargo",
-    version,
-    propagate_version = true,
-)]
+#[clap(name = "cargo", bin_name = "cargo", version, propagate_version = true)]
 struct CargoCommand {
     #[clap(subcommand)]
     subcommand: CargoSubcommands,
@@ -52,12 +46,21 @@ impl CommandExecute for CargoSubcommands {
 }
 
 fn main() -> color_eyre::Result<()> {
-    color_eyre::install()?;
+    color_eyre::config::HookBuilder::default()
+        .theme(if !atty::is(Stream::Stderr) {
+            color_eyre::config::Theme::new()
+        } else {
+            color_eyre::config::Theme::default()
+        })
+        .install()?;
 
     let cargo_cli = CargoCommand::parse();
 
     // Initialize tracing with tracing-error, and eyre
-    let fmt_layer = tracing_subscriber::fmt::Layer::new().pretty();
+    let fmt_layer = tracing_subscriber::fmt::Layer::new()
+        .with_ansi(atty::is(Stream::Stderr))
+        .with_writer(std::io::stderr)
+        .pretty();
 
     let filter_layer = match EnvFilter::try_from_default_env() {
         Ok(filter_layer) => filter_layer,
